@@ -32,8 +32,12 @@ LIBICAL_ICALSS_EXPORT icalgauge *icalgauge_new_from_sql(const char *sql, int exp
  */
 LIBICAL_ICALSS_EXPORT int icalgauge_get_expand(icalgauge *gauge);
 LIBICAL_ICALSS_EXPORT void icalgauge_free(icalgauge *gauge);
+/** @brief Debug
+ *
+ * Prints gauge information to STDOUT.
+ */
 LIBICAL_ICALSS_EXPORT void icalgauge_dump(icalgauge *gauge);
-/** @brief Return true if comp matches the gauge.
+/** @brief Returns true if comp matches the gauge.
  *
  * The component must be in
  * cannonical form -- a VCALENDAR with one VEVENT, VTODO or VJOURNAL
@@ -110,7 +114,7 @@ struct icalset_impl
     icalcomponent *(*icalsetiter_to_next) (icalset *set, icalsetiter *i);
     icalcomponent *(*icalsetiter_to_prior) (icalset *set, icalsetiter *i);
 };
-/** @brief Register a new derived class */
+/** @brief Registers a new derived class */
 LIBICAL_ICALSS_EXPORT int icalset_register_class(icalset *set);
 /** @brief Generic icalset constructor
  *
@@ -127,28 +131,32 @@ LIBICAL_ICALSS_EXPORT icalset *icalset_new_file(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalset_new_file_reader(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalset_new_file_writer(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalset_new_dir(const char *path);
+/**
+ *  Frees the memory associated with this icalset
+ *  automatically calls the implementation specific free routine
+ */
 LIBICAL_ICALSS_EXPORT void icalset_free(icalset *set);
 LIBICAL_ICALSS_EXPORT const char *icalset_path(icalset *set);
-/** Mark the cluster as changed, so it will be written to disk when it
+/** Marks the cluster as changed, so it will be written to disk when it
     is freed. **/
 LIBICAL_ICALSS_EXPORT void icalset_mark(icalset *set);
-/** Write changes to disk immediately */
+/** Writes changes to disk immediately */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_commit(icalset *set);
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_add_component(icalset *set, icalcomponent *comp);
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_remove_component(icalset *set, icalcomponent *comp);
 LIBICAL_ICALSS_EXPORT int icalset_count_components(icalset *set, icalcomponent_kind kind);
-/** Restrict the component returned by icalset_first, _next to those
+/** Restricts the component returned by icalset_first, _next to those
     that pass the gauge. */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_select(icalset *set, icalgauge *gauge);
-/** Get a component by uid */
+/** Gets a component by uid */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalset_fetch(icalset *set, const char *uid);
 LIBICAL_ICALSS_EXPORT int icalset_has_uid(icalset *set, const char *uid);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalset_fetch_match(icalset *set, icalcomponent *c);
-/** Modify components according to the MODIFY method of CAP. Works on
+/** Modifies components according to the MODIFY method of CAP. Works on
    the currently selected components. */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_modify(icalset *set,
                                                    icalcomponent *oldc, icalcomponent *newc);
-/** Iterate through the components. If a guage has been defined, these
+/** Iterates through the components. If a guage has been defined, these
    will skip over components that do not pass the gauge */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalset_get_current_component(icalset *set);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalset_get_first_component(icalset *set);
@@ -234,25 +242,26 @@ LIBICAL_ICALSS_EXPORT icalerrorenum icalfileset_remove_component(icalset *set,
                                                                  icalcomponent *child);
 LIBICAL_ICALSS_EXPORT int icalfileset_count_components(icalset *set, icalcomponent_kind kind);
 /**
- * Restrict the component returned by icalfileset_first, _next to those
- * that pass the gauge. _clear removes the gauge
+ * Restricts the component returned by icalfileset_first, _next to those
+ * that pass the gauge. _clear removes the gauge.
  */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalfileset_select(icalset *set, icalgauge *gauge);
-/** clear the gauge **/
+/** @brief Clears the gauge **/
 LIBICAL_ICALSS_EXPORT void icalfileset_clear(icalset *set);
-/** Get and search for a component by uid **/
+/** @brief Gets and searches for a component by uid **/
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_fetch(icalset *set,
                                                        icalcomponent_kind kind, const char *uid);
 LIBICAL_ICALSS_EXPORT int icalfileset_has_uid(icalset *set, const char *uid);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_fetch_match(icalset *set, icalcomponent *c);
 /**
- *  Modify components according to the MODIFY method of CAP. Works on the
- *  currently selected components.
+ *  @brief Modifies components according to the MODIFY method of CAP.
+ *
+ *  Works on the currently selected components.
  */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalfileset_modify(icalset *set,
                                                        icalcomponent *oldcomp,
                                                        icalcomponent *newcomp);
-/* Iterate through components. If a gauge has been defined, these
+/* Iterates through components. If a gauge has been defined, these
    will skip over components that do not pass the gauge */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_get_current_component(icalset *cluster);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_get_first_component(icalset *cluster);
@@ -264,11 +273,11 @@ LIBICAL_ICALSS_EXPORT icalsetiter icalfileset_begin_component(icalset *set,
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfilesetiter_to_next(icalset *set, icalsetiter *iter);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_form_a_matched_recurrence_component(icalsetiter *
                                                                                      itr);
-/** Return a reference to the internal component. You probably should
-   not be using this. */
+/** Returns a reference to the internal component. **You probably should
+   not be using this.** */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalfileset_get_component(icalset *cluster);
 /**
- * @brief options for opening an icalfileset.
+ * @brief Options for opening an icalfileset.
  *
  * These options should be passed to the icalset_new() function
  */
@@ -295,6 +304,26 @@ extern icalfileset_options icalfileset_options_default;
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
 ======================================================================*/
+/**
+   @file   icaldirset.h
+   @brief  icaldirset manages a database of ical components and offers
+  interfaces for reading, writing and searching for components.
+  icaldirset groups components in to clusters based on their DTSTAMP
+  time -- all components that start in the same month are grouped
+  together in a single file. All files in a sotre are kept in a single
+  directory.
+  The primary interfaces are icaldirset__get_first_component and
+  icaldirset_get_next_component. These routine iterate through all of
+  the components in the store, subject to the current gauge. A gauge
+  is an icalcomponent that is tested against other componets for a
+  match. If a gauge has been set with icaldirset_select,
+  icaldirset_first and icaldirset_next will only return componentes
+  that match the gauge.
+  The Store generated UIDs for all objects that are stored if they do
+  not already have a UID. The UID is the name of the cluster (month &
+  year as MMYYYY) plus a unique serial number. The serial number is
+  stored as a property of the cluster.
+*/
 #ifndef ICALDIRSET_H
 #define ICALDIRSET_H
 #include "libical_icalss_export.h"
@@ -307,28 +336,33 @@ LIBICAL_ICALSS_EXPORT icalset *icaldirset_new_writer(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icaldirset_init(icalset *set, const char *dsn, void *options);
 LIBICAL_ICALSS_EXPORT void icaldirset_free(icalset *set);
 LIBICAL_ICALSS_EXPORT const char *icaldirset_path(icalset *set);
-/* Mark the cluster as changed, so it will be written to disk when it
+/* Marks the cluster as changed, so it will be written to disk when it
    is freed. Commit writes to disk immediately*/
 LIBICAL_ICALSS_EXPORT void icaldirset_mark(icalset *set);
 LIBICAL_ICALSS_EXPORT icalerrorenum icaldirset_commit(icalset *set);
+/**
+  This assumes that the top level component is a VCALENDAR, and there
+   is an inner component of type VEVENT, VTODO or VJOURNAL. The inner
+  component must have a DSTAMP property
+*/
 LIBICAL_ICALSS_EXPORT icalerrorenum icaldirset_add_component(icalset *store, icalcomponent *comp);
 LIBICAL_ICALSS_EXPORT icalerrorenum icaldirset_remove_component(icalset *store,
                                                                 icalcomponent *comp);
 LIBICAL_ICALSS_EXPORT int icaldirset_count_components(icalset *store, icalcomponent_kind kind);
-/* Restrict the component returned by icaldirset_first, _next to those
+/* Restricts the component returned by icaldirset_first, _next to those
    that pass the gauge. _clear removes the gauge. */
 LIBICAL_ICALSS_EXPORT icalerrorenum icaldirset_select(icalset *store, icalgauge *gauge);
 LIBICAL_ICALSS_EXPORT void icaldirset_clear(icalset *store);
-/* Get a component by uid */
+/* Gets a component by uid */
 LIBICAL_ICALSS_EXPORT icalcomponent *icaldirset_fetch(icalset *store,
                                                       icalcomponent_kind kind, const char *uid);
 LIBICAL_ICALSS_EXPORT int icaldirset_has_uid(icalset *store, const char *uid);
 LIBICAL_ICALSS_EXPORT icalcomponent *icaldirset_fetch_match(icalset *set, icalcomponent *c);
-/* Modify components according to the MODIFY method of CAP. Works on
+/* Modifies components according to the MODIFY method of CAP. Works on
    the currently selected components. */
 LIBICAL_ICALSS_EXPORT icalerrorenum icaldirset_modify(icalset *store,
                                                       icalcomponent *oldc, icalcomponent *newc);
-/* Iterate through the components. If a gauge has been defined, these
+/* Iterates through the components. If a gauge has been defined, these
    will skip over components that do not pass the gauge */
 LIBICAL_ICALSS_EXPORT icalcomponent *icaldirset_get_current_component(icalset *store);
 LIBICAL_ICALSS_EXPORT icalcomponent *icaldirset_get_first_component(icalset *store);
@@ -361,11 +395,14 @@ typedef struct icaldirset_options
 #ifndef ICALCALENDAR_H
 #define ICALCALENDAR_H
 #include "libical_icalss_export.h"
-/* icalcalendar
- * Routines for storing calendar data in a file system. The calendar
- * has two icaldirsets, one for incoming components and one for booked
- * components. It also has interfaces to access the free/busy list
- * and a list of calendar properties */
+/** @file icalcalendar.h
+ *
+ * @brief Routines for storing calendar data in a file system.
+ *
+ * The calendar has two icaldirsets, one for incoming components and one for
+ * booked components. It also has interfaces to access the free/busy list and a
+ * list of calendar properties
+ */
 typedef struct icalcalendar_impl icalcalendar;
 LIBICAL_ICALSS_EXPORT icalcalendar *icalcalendar_new(const char *dir);
 LIBICAL_ICALSS_EXPORT void icalcalendar_free(icalcalendar *calendar);
@@ -417,26 +454,87 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalclassify_find_overlaps(icalset *set,
  *  @brief Code that supports collections of free/busy spans of time
  */
 typedef struct icalspanlist_impl icalspanlist;
-/** @brief Constructor
- * Make a free list from a set of component. Start and end should be in UTC
+/** @brief Makes a free list from a set of VEVENT components.
+ *
+ *  @param set    A valid icalset containing VEVENTS
+ *  @param start  The free list starts at this date/time
+ *  @param end    The free list ends at this date/time
+ *
+ *  @return        A spanlist corresponding to the VEVENTS
+ *
+ * Given a set of components, a start time and an end time
+ * return a spanlist that contains the free/busy times.
+ * @p Start and @p end should be in UTC.
  */
 LIBICAL_ICALSS_EXPORT icalspanlist *icalspanlist_new(icalset *set,
                                                      struct icaltimetype start,
                                                      struct icaltimetype end);
-/** @brief Destructor
+/** @brief Destructor.
+ *  @param s A valid icalspanlist
+ *
+ *  Frees the memory associated with the spanlist.
  */
 LIBICAL_ICALSS_EXPORT void icalspanlist_free(icalspanlist *spl);
-/** Get first next free time after time t. all times are in UTC. */
+/** @brief Finds the next free time span in a spanlist.
+ *
+ *  @param  sl     The spanlist to search.
+ *  @param  t      The time to start looking.
+ *
+ *  Given a spanlist and a time, finds the next period of time
+ *  that is free.
+ */
 LIBICAL_ICALSS_EXPORT struct icalperiodtype icalspanlist_next_free_time(icalspanlist *sl,
                                                                         struct icaltimetype t);
+/** @brief (Debug) print out spanlist to STDOUT.
+ *  @param sl A valid icalspanlist.
+ */
 LIBICAL_ICALSS_EXPORT void icalspanlist_dump(icalspanlist *s);
-/** @brief Return a valid VFREEBUSY component for this span */
+/** @brief Returns a VFREEBUSY component for a spanlist.
+ *
+ *   @param sl         A valid icalspanlist, from icalspanlist_new()
+ *   @param organizer  The organizer specified as "MAILTO:user@domain"
+ *   @param attendee   The attendee specified as "MAILTO:user@domain"
+ *
+ *   @return            A valid icalcomponent or NULL.
+ *
+ * This function returns a VFREEBUSY component for the given spanlist.
+ * The start time is mapped to DTSTART, the end time to DTEND.
+ * Each busy span is represented as a separate FREEBUSY entry.
+ * An attendee parameter is required, and organizer parameter is
+ * optional.
+ */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalspanlist_as_vfreebusy(icalspanlist *sl,
                                                                const char *organizer,
                                                                const char *attendee);
-/** @brief Return an integer matrix of total events per delta_t timespan */
+/** @brief Returns an hour-by-hour array of free/busy times over a
+ *         given period.
+ *
+ *  @param sl        A valid icalspanlist
+ *  @param delta_t   The time slice to divide by, in seconds.  Default 3600.
+ *
+ *  @return A pointer to an array of integers containing the number of
+ *       busy events in each delta_t time period.  The final entry
+ *       contains the value -1.
+ *
+ *  This calculation is somewhat tricky.  This is due to the fact that
+ *  the time range contains the start time, but does not contain the
+ *  end time.  To perform a proper calculation we subtract one second
+ *  off the end times to get a true containing time.
+ *
+ *  Also note that if you supplying a spanlist that does not start or
+ *  end on a time boundary divisible by delta_t you may get results
+ *  that are not quite what you expect.
+ */
 LIBICAL_ICALSS_EXPORT int *icalspanlist_as_freebusy_matrix(icalspanlist *span, int delta_t);
-/** @brief Construct an icalspanlist from a VFREEBUSY component */
+/** @brief Constructs an icalspanlist from a VFREEBUSY component */
+/** @brief Constructs an icalspanlist from the VFREEBUSY component of
+ *         an icalcomponent.
+ *
+ *   @param   comp     A valid icalcomponent.
+ *
+ *   @return           A valid icalspanlist or NULL if no VFREEBUSY section.
+ *
+ */
 LIBICAL_ICALSS_EXPORT icalspanlist *icalspanlist_from_vfreebusy(icalcomponent *comp);
 #endif
 /*======================================================================
@@ -544,7 +642,7 @@ LIBICAL_ICALSS_EXPORT int icalbdbset_count_components(icalset *set, icalcomponen
    that pass the gauge. _clear removes the gauge */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_select(icalset *store, icalgauge *gauge);
 LIBICAL_ICALSS_EXPORT void icalbdbset_clear(icalset *store);
-/* Get and search for a component by uid */
+/* Gets and searches for a component by uid */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_fetch(icalset *set,
                                                       icalcomponent_kind kind, const char *uid);
 LIBICAL_ICALSS_EXPORT int icalbdbset_has_uid(icalset *set, const char *uid);
